Enum ButtonSource
pub enum ButtonSource {
Mouse(MouseButton),
Touch {
finger_id: FingerId,
force: Option<Force>,
},
TabletTool {
kind: TabletToolKind,
button: TabletToolButton,
data: TabletToolData,
},
Unknown(u16),
}Expand description
Represents the pointer type of a WindowEvent::PointerButton.
Wayland/X11: Unknown device types are converted to known variants by the
system.
Variants
Mouse(MouseButton)
Touch
TabletTool
Unknown(u16)
A pointer button of unknown source.
Codes are undefined and may not be reproducible across platforms or winit versions.
Implementations
impl ButtonSource
impl ButtonSource
Try to convert a ButtonSource to an equivalent MouseButton. If a pointer type has no
special handling in an application, this method can be used to handle it like any generic
mouse input.