Struct SurfaceSizeWriter
pub struct SurfaceSizeWriter { /* private fields */ }Expand description
Handle to synchronously change the size of the window from the WindowEvent.
Implementations
impl SurfaceSizeWriter
impl SurfaceSizeWriter
pub fn new( new_surface_size: Weak<Mutex<PhysicalSize<u32>>>, ) -> SurfaceSizeWriter
pub fn request_surface_size(
&mut self,
new_surface_size: PhysicalSize<u32>,
) -> Result<(), RequestError>
pub fn request_surface_size( &mut self, new_surface_size: PhysicalSize<u32>, ) -> Result<(), RequestError>
Try to request surface size which will be set synchronously on the window.
pub fn surface_size(&self) -> Result<PhysicalSize<u32>, RequestError>
pub fn surface_size(&self) -> Result<PhysicalSize<u32>, RequestError>
Get the currently stashed surface size.