Struct TabletToolAngle
pub struct TabletToolAngle {
pub altitude: f64,
pub azimuth: f64,
}Expand description
The angular position in radians of a tool.
Fields
altitude: f64The altitude angle in radians between the tools perpendicular position to the surface and the surface X-Y plane. In the range of 0, parallel to the surface, to π/2, perpendicular to the surface. π/2 means the tool is perpendicular to the surface and is the default.

azimuth: f64The azimuth angle in radiants representing the rotation between the major axis of the tool
and the surface X-Y plane. In the range of 0, 3 o’clock, progressively increasing clockwise
to 2π. 0 means the tool is at 3 o’clock or is perpendicular to the surface (altitude of
π/2) and is the default.

Implementations
impl TabletToolAngle
impl TabletToolAngle
pub fn tilt(self) -> TabletToolTilt