Struct TabletToolTilt
pub struct TabletToolTilt {
pub x: i8,
pub y: i8,
}Expand description
The plane angle in degrees of a tool.
Fields
x: i8The plane angle in degrees between the surface Y-Z plane and the plane containing the tool and the surface Y axis. Positive values are to the right. In the range of -90 to 90. 0 means the tool is perpendicular to the surface and is the default.

y: i8The plane angle in degrees between the surface X-Z plane and the plane containing the tool and the surface X axis. Positive values are towards the user. In the range of -90 to 90. 0 means the tool is perpendicular to the surface and is the default.

Implementations
impl TabletToolTilt
impl TabletToolTilt
pub fn angle(self) -> TabletToolAngle